@@ -24,7 +24,7 @@ from octavia_lib.tests.unit import base
 class TestProviderDataModels(base.TestCase):
 
     def setUp(self):
-        super(TestProviderDataModels, self).setUp()
+        super().setUp()
 
         self.loadbalancer_id = uuidutils.generate_uuid()
         self.project_id = uuidutils.generate_uuid()
@@ -107,7 +107,14 @@ class TestProviderDataModels(base.TestCase):
                           constants.TLS_VERSION_1_1,
                           constants.TLS_VERSION_1_2,
                           constants.TLS_VERSION_1_3],
-            tls_ciphers=None)
+            tls_ciphers=None,
+            alpn_protocols=[constants.ALPN_PROTOCOL_HTTP_1_0,
+                            constants.ALPN_PROTOCOL_HTTP_1_1,
+                            constants.ALPN_PROTOCOL_HTTP_2],
+            hsts_max_age=None,
+            hsts_include_subdomains=None,
+            hsts_preload=None,
+        )
 
         self.ref_lb = data_models.LoadBalancer(
             admin_state_up=False,
@@ -180,7 +187,10 @@ class TestProviderDataModels(base.TestCase):
                           constants.TLS_VERSION_1_1,
                           constants.TLS_VERSION_1_2,
                           constants.TLS_VERSION_1_3],
-            tls_ciphers=None)
+            tls_ciphers=None,
+            alpn_protocols=[constants.ALPN_PROTOCOL_HTTP_1_0,
+                            constants.ALPN_PROTOCOL_HTTP_1_1,
+                            constants.ALPN_PROTOCOL_HTTP_2])
 
         self.ref_l7rule_dict = {'admin_state_up': True,
                                 'compare_type': 'STARTS_WITH',
@@ -253,7 +263,14 @@ class TestProviderDataModels(base.TestCase):
                              constants.TLS_VERSION_1_1,
                              constants.TLS_VERSION_1_2,
                              constants.TLS_VERSION_1_3],
-            'tls_ciphers': None}
+            'tls_ciphers': None,
+            'alpn_protocols': [constants.ALPN_PROTOCOL_HTTP_1_0,
+                               constants.ALPN_PROTOCOL_HTTP_1_1,
+                               constants.ALPN_PROTOCOL_HTTP_2],
+            'hsts_max_age': None,
+            'hsts_include_subdomains': None,
+            'hsts_preload': None,
+        }
 
         self.ref_lb_dict_with_listener = {
             'admin_state_up': False,
@@ -268,7 +285,8 @@ class TestProviderDataModels(base.TestCase):
             'vip_port_id': self.vip_port_id,
             'vip_subnet_id': self.vip_subnet_id,
             'vip_qos_policy_id': self.vip_qos_policy_id,
-            'availability_zone': self.availability_zone}
+            'availability_zone': self.availability_zone,
+        }
 
         self.ref_vip_dict = {
             'vip_address': self.vip_address,
@@ -326,7 +344,10 @@ class TestProviderDataModels(base.TestCase):
                              constants.TLS_VERSION_1_1,
                              constants.TLS_VERSION_1_2,
                              constants.TLS_VERSION_1_3],
-            'tls_ciphers': None}
+            'tls_ciphers': None,
+            'alpn_protocols': [constants.ALPN_PROTOCOL_HTTP_1_0,
+                               constants.ALPN_PROTOCOL_HTTP_1_1,
+                               constants.ALPN_PROTOCOL_HTTP_2]}
 
     def test_equality(self):
         second_ref_lb = deepcopy(self.ref_lb)
@@ -367,10 +388,12 @@ class TestProviderDataModels(base.TestCase):
         ref_list_dict.pop('sni_container_data', None)
         ref_list_dict.pop('sni_container_refs', None)
         ref_list_dict.pop('tls_versions', None)
+        ref_list_dict.pop('alpn_protocols', None)
         ref_pool_dict = deepcopy(self.ref_pool_dict)
         ref_pool_dict['healthmonitor'] = None
         ref_pool_dict.pop('members', None)
         ref_pool_dict.pop('tls_versions', None)
+        ref_pool_dict.pop('alpn_protocols', None)
         ref_l7policy_dict = deepcopy(self.ref_l7policy_dict)
         ref_l7policy_dict.pop('rules', None)
 
